@@ -1,5 +1,5 @@
 import tkinter as tk
-from typing import Optional, Any, override
+from typing import Optional, Any
 from .core import Screen
 
 class Object:
@@ -11,6 +11,10 @@ class Object:
         self
     ) -> None: ...
 
+    def config(
+        self
+    ) -> None: ...
+
     def destroy(
         self
     ) -> None: ...
@@ -30,13 +34,23 @@ class Button(Object):
         packargs: Optional[dict[Any, Optional[Any]]] = None,
         **kwargs: Any
     ) -> None:
+        if not isinstance(screen_obj, Screen):
+            raise TypeError("screen_obj must be an instance of Screen")
+
         if packargs is None:
             packargs = {}
 
         self.button_obj = tk.Button(screen_obj.root, **kwargs)
         self.button_obj.pack(**{k: v for k, v in packargs.items() if v is not None})
 
-    @override
+    def config(
+        self,
+        **kwargs
+    ) -> None:
+        """Configure object"""
+
+        self.button_obj.config(**kwargs)
+
     def destroy(
         self
     ) -> None:
@@ -59,13 +73,24 @@ class Text(Object):
         packargs: Optional[dict[Any, Optional[Any]]] = None,
         **kwargs: Any
     ) -> None:
+        if not isinstance(screen_obj, Screen):
+            raise TypeError("screen_obj must be an instance of Screen")
+
         if packargs is None:
             packargs = {}
 
         self.text_obj = tk.Label(screen_obj.root, **kwargs)
         self.text_obj.pack(**{k: v for k, v in packargs.items() if v is not None})
 
-    @override
+    def config(
+        self,
+        **kwargs
+    ) -> None:
+        """Configure object"""
+
+        self.text_obj.config(**kwargs)
+
+
     def destroy(
         self
     ) -> None:
@@ -88,6 +113,9 @@ class Input(Object):
         packargs: Optional[dict[Any, Optional[Any]]] = None,
         **kwargs: Any
     ) -> None:
+        if not isinstance(screen_obj, Screen):
+            raise TypeError("screen_obj must be an instance of Screen")
+
         if packargs is None:
             packargs = {}
 
@@ -97,9 +125,18 @@ class Input(Object):
     def get(
         self
     ) -> str:
+        """Get input box value"""
+
         return self.input_obj.get()
 
-    @override
+    def config(
+        self,
+        **kwargs
+    ) -> None:
+        """Configure object"""
+
+        self.input_obj.config(**kwargs)
+
     def destroy(
         self
     ) -> None:
